.. _spkg_configure:

configure: Files of the Sage distribution that are autogenerated in the bootstrapping phase
===========================================================================================

Description
-----------

This package contains a tar archive of auto-generated files. They are
shipped with Sage in case you do not have a sufficiently recent
autotools version installed.

License
-------

GPLv3+


Upstream Contact
----------------

Automatically generated by Sage, use trac and/or sage-devel for
questions.

Special Update/Build Instructions
---------------------------------

This tarball is automatically generated by Sage whenever you run the
$SAGE_ROOT/bootstrap -s or the $SAGE_ROOT/tools/update-version
script.


Type
----

base


Dependencies
------------



Version Information
-------------------

package-version.txt::

    089d7672a2bebe026a2b21c38c4ab8cc8f818d84

Installation commands
---------------------

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i configure


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
